import React, { useState, useEffect } from "react";
import { Col, Row, Button } from "react-bootstrap";
import { Link } from "react-router-dom";
import { connect, useDispatch } from "react-redux";
import { actions as cartActions } from "@redux/cartRedux";
import { actions as favoriteActions } from "@redux/favoriteRedux";
import SpinnerLocal from "components/spinner";
import cartServices from "services/cartServices";
import favoriteServices from "services/favouriteServices";
import { Cart } from "models/cart";
import { isUserLoggedIn } from "services/userServices";
import { parse } from "@fortawesome/fontawesome-svg-core";
import SliderDataAccess from "dataAccess/sliderDataAccess";
import { toast } from "react-toastify";
import { Helmet } from "react-helmet";
import {FiTrash} from "react-icons/fi";

const MyProfileShoppingCart = (props) => {
  const dispatch = useDispatch();

  const [currency, setCurrency] = useState(null);

  useEffect(() => {
    SliderDataAccess.getSettingData()
      .then((data) => {
        setCurrency(data.currency_symbol);
      })
      .catch((error) => {});
  }, []);

  useEffect(() => {
    dispatch(cartActions.getCartProducts(props.cart.cart));
  }, [dispatch, props.cart.cart]);

   if(props.cart.productsLoading==true)
   {
      return <SpinnerLocal height="75vh"/>;
   }

  if (props.cart.productsError) {
    return <div>Something went wrong</div>;
  }
  return (
    <div className="user-profile-top">
      <Helmet>
        <title> Genx | Cart </title>
        <meta name="description" content="My Shopping Cart" />
      </Helmet>
      <div className="create-account-container contact-us-bottom profile-bottom">
        <Row>
          <Col className="sideNav">
            <Row className="shopping-cart-container">
              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
                className="first-section"
              >
                <div>
                  <span className="header"> Shopping Cart </span>
                </div>
              </Col>
              <hr style={{ width: "100%" }} />
              {props.cart.products && props.cart.products.length > 0 ? (
                props.cart.cart.map((cart: Cart, index) => {
                  const product = cartServices.getCartProduct(
                    cart,
                    props.cart.products
                  );
                  if (!product) {
                    return null;
                  }
                  return (
                    <Col
                      xl={12}
                      lg={12}
                      md={12}
                      sm={12}
                      xs={12}
                      className="second-section"
                      key={product.id}
                    >
                      <Row>
                        <Col xl={3} lg={3} md={3} sm={12} xs={12}>
                          <Row>
                            <Col>
                              <img
                                src={product.image1}
                                alt=""
                                className="left-img-circle"
                              />
                            </Col>
                            <Col>
                              <h4 style={{ fontSize: "12px" }}>
                                {product.name}
                              </h4>

                              {parseFloat(product.discount_price) > 0 && (
                                <div>
                                  <span style={{ color: "#40bfff" }}>
                                    {" "}
                                    {currency} {product.discount_price}{" "}
                                  </span>{" "}
                                  &nbsp;
                                  <del
                                    className="price"
                                    style={{ color: "red" }}
                                  >
                                    {" "}
                                    {currency} {product.price}{" "}
                                  </del>
                                </div>
                              )}
                              {parseFloat(product.discount_price) == 0 && (
                                <span
                                  className="price"
                                  style={{ color: "#40bfff" }}
                                >
                                  {" "}
                                  {currency} {product.price}{" "}
                                </span>
                              )}
                            </Col>
                          </Row>
                        </Col>
                        <Col
                          xl={3}
                          lg={3}
                          md={3}
                          sm={12}
                          xs={12}
                          className="cancel-and-favorite mobile-view-shopping-cart"
                        >
                          &nbsp; &nbsp;
                          {favoriteServices.isProductOnFavorite(
                            product.id,
                            props.favorite.favorite
                          ) ? (
                            <img
                              onClick={() => {
                                dispatch(
                                  favoriteActions.removeProductFromFavorite(
                                    product.id,
                                    isUserLoggedIn(props.user.user)
                                  )
                                );
                              }}
                              width="24px"
                              height="20px"
                              src="/images/heartyelo.png"
                              alt=""
                            />
                          ) : (
                            <img
                              onClick={() => {
                                dispatch(
                                  favoriteActions.addProductToFavorite(
                                    product.id,
                                    isUserLoggedIn(props.user.user)
                                  )
                                );
                              }}
                              width="24px"
                              height="20px"
                              src="/images/heart.png"
                              alt=""
                            />
                          )}
                        </Col>
                        <Col
                          xl={3}
                          lg={3}
                          md={3}
                          sm={12}
                          xs={12}
                          className="cart-button-plus mobile-view-shopping-cart"
                        >
                          <img
                            onClick={() => {
                              dispatch(
                                cartActions.decreaseProductQuantity(
                                  cart.id,
                                  cart.quantity,
                                  isUserLoggedIn(props.user.user)
                                )
                              );
                            }}
                            src="images/MinusCart.png"
                            alt=""
                          />
                          <span> &nbsp; {cart.quantity} &nbsp; </span>
                          <img
                            onClick={() => {
                              cartServices.getCartQuantity(
                                product.id,
                                props.cart.cart
                              ) === product.quantity
                                ? toast.error("stock out")
                                : dispatch(
                                    cartActions.increaseProductQuantity(
                                      cart.id,
                                      cart.quantity,
                                      isUserLoggedIn(props.user.user)
                                    )
                                  );
                            }}
                            src="images/AddCart.png"
                            alt=""
                          />
                        </Col>
                        <Col
                          xl={3}
                          lg={3}
                          md={3}
                          sm={12}
                          xs={12}
                          className="mobile-view-shopping-cart"
                        >
                          <div className="d-flex justify-content-end pr-4">
                            <h5 className="total-price">
                              <strong>
                                {parseFloat(product.discount_price) == 0.0 && (
                                    <span>
                                  {currency}{" "}
                                      {parseFloat(product.price) * cart.quantity}{" "}
                                </span>
                                )}
                              </strong>
                              <strong>
                                {parseFloat(product.discount_price) > 0.0 && (
                                    <span>
                                  {currency}{" "}
                                      {parseFloat(product.discount_price) *
                                      cart.quantity}{" "}
                                </span>
                                )}
                              </strong>
                            </h5>
                            <div className="ml-4">
                              <FiTrash onClick={() => {
                                dispatch(
                                    cartActions.removeFromCart(
                                        cart.id,
                                        isUserLoggedIn(props.user.user)
                                    )
                                );
                              }} className="total-price" size={22} style={{marginTop: -4, cursor: 'pointer'}}/>
                            </div>
                          </div>
                        </Col>
                      </Row>
                      <br />
                    </Col>
                  );
                })
              ) : (
                <div className="no-product-on-cart">
                  {" "}
                  <span> No products on cart </span>{" "}
                </div>
              )}
              <hr style={{ width: "96%" }} />

              {/*
                     <Col xl={12} lg={12} md={12} sm={12} xs={12} className="third-section">
                        <span className="sub-total"> Sub Total: </span>
                        <span className="sub-total-price">
                           {" "}
                           {props.cart.products && props.cart.cart
                              ? cartServices.getTotalPrice(props.cart.products, props.cart.cart)
                              : 0}{" "}
                           tk{" "}
                        </span>
                     </Col> */}

              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
                className="five-section"
              >
                <span className="net-total"> Sub Total: </span>
                <span className="net-price">
                  <h4>
                    <strong>
                      {currency}{" "}
                      {props.cart.products && props.cart.cart
                        ? cartServices.getTotalPrice(
                            props.cart.products,
                            props.cart.cart
                          )
                        : 0}
                      &nbsp;
                    </strong>
                  </h4>
                </span>
              </Col>
              <Col
                xl={12}
                lg={12}
                md={12}
                sm={12}
                xs={12}
                className="six-section"
              >
                <Button
                  onClick={() => {
                    props.history.push("/");
                  }}
                  className="continue-shopping-btn"
                >
                  <img src="images/arrow-rightt.png" alt="" />
                  <span className="btn-text"> Continue Shopping </span>
                </Button>
                <Link to="/checkout">
                  <Button variant="primary" className="checkout">
                    <span className="btn-text"> Checkout </span>
                  </Button>
                </Link>
              </Col>
            </Row>
          </Col>
        </Row>
      </div>
    </div>
  );
};
const mapStateToProps = ({ cart, user, favorite }) => ({
  cart,
  user,
  favorite,
});

export default connect(mapStateToProps)(MyProfileShoppingCart);
